@@ -330,17 +330,17 @@
 
       RETURN
 *-----------------------------------------------------------------------
-      ENTRY SWSCLI(ICLIDX)
+      ENTRY SWSCLI(ICLIDX,LFCATR)
 
 *     / SET LINE COLOR INDEX /
-*      IF(.NOT.LFCATR) THEN
+      IF(.NOT.LFCATR) THEN
 
       IF (IWS.EQ.1) CALL ZMSCLI(ICLIDX)
       IF (IWS.EQ.2) CALL ZMSCLI(ICLIDX)
       IF (IWS.EQ.3) CALL Z1SCLI(ICLIDX)
       IF (IWS.EQ.4) CALL ZGSCLI(ICLIDX)
 
-*      ELSE
+      ELSE
 
       CALL SGQCL(ICLIDX,NR,NB,NG)
       CALL UIFPAC(NR,NG,NB,NCOLOR)
@@ -350,11 +350,7 @@
       IF (IWS.EQ.3) CALL Z1SLCL(NCOLOR)
       IF (IWS.EQ.4) CALL ZGSLCL(NCOLOR)
 
-*      ENDIF
-
-*      IF (IWS.EQ.1) CALL ZMSCLI(ICLIDX)
-*      IF (IWS.EQ.2) CALL ZMSCLI(ICLIDX)
-*      IF (IWS.EQ.3) CALL Z1SCLI(ICLIDX)
+      ENDIF
 
       RETURN
 *-----------------------------------------------------------------------
@@ -474,9 +470,14 @@
       ENTRY SWIOPN(IWX,IWY,IMW,IMH)
 
 *     / OPEN IMAGE /
+*      IF (.NOT. LOPEN)
+*     +   CALL MSGDMP('E', 'SWIOPN', CNOPN)
       IF (IWS.EQ.1) CALL ZMIOPN(IWX, IWY, IMW, IMH)
       IF (IWS.EQ.2) CALL ZMIOPN(IWX, IWY, IMW, IMH)
-      IF (IWS.EQ.3) CALL Z1IOPN(IWX, IWY, IMW, IMH)
+      IF (IWS.EQ.3) THEN
+        CALL Z1CLIP(WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)
+        CALL Z1IOPN(IWX, IWY, IMW, IMH)
+      ENDIF
       IF (IWS.EQ.4) CALL ZGIOPN(IWX, IWY, IMW, IMH)
 
       RETURN
