@@ -91,6 +91,12 @@
           IF (UX.EQ.RUNDEF) THEN
             IMAGE(I) = 0
           ELSE
+
+
+  360     IF (UY.LT.0) UY=UY+360
+          IF (UY.GE.360) UY=UY-360
+          IF ((UY.LT.0).OR.(UY.GE.360)) GOTO 360
+
             CALL UWQGXI(UX,IX,FX)
             CALL UWQGYI(UY,IY,FY)
             IF (IX.EQ.IUNDEF .OR. IY.EQ.IUNDEF) THEN
